==> eclipsefdn-solstice-assets-0.0.171.tgz: package/NOTICE.md <==
# Notices for solstice-assets

This content is produced and maintained by the Eclipse Foundation.

* Project home: https://github.com/eclipsefdn/solstice-assets

## Trademarks

* Jakarta and Jakarta EE are Trademarks of the Eclipse Foundation, Inc.
* Eclipse® is a Trademark of the Eclipse Foundation, Inc.
* Eclipse Foundation is a Trademark of the Eclipse Foundation, Inc.

## Copyright

All content is the property of the respective authors or their employers. For
more information regarding authorship of content, please consult the listed
source code repository logs.

## Declared Project Licenses

This program and the accompanying materials are made available under the terms
of the Eclipse Public License v. 2.0 which is available at
http://www.eclipse.org/legal/epl-2.0.

SPDX-License-Identifier: EPL-2.0

## Source Code

The project maintains the following source code repositories:

* https://github.com/eclipsefdn/solstice-assets

## Third-party Content

### Drupal-Bootstrap (7.x-3.20)

* License: The GPL License (GPL)

### Yamm (master)

* License: The MIT License (MIT)

### Bootstrap (^3.3.7)

* License: The MIT License (MIT)

### Feather (^4.7.0)

* License: The MIT License (MIT)

### Font-Awesome (^4.7.0)

* The Font Awesome font is licensed under the SIL OFL 1.1:
** http://scripts.sil.org/OFL
* Font Awesome CSS, LESS, and Sass files are licensed under the MIT License:
** https://opensource.org/licenses/mit-license.html
* The Font Awesome documentation is licensed under the CC BY 3.0 License:
** https://creativecommons.org/licenses/by/3.0/
* Attribution is no longer required as of Font Awesome 3.0, but much appreciated:
** `Font Awesome by Dave Gandy - http://fontawesome.io`
* Full details: http://fontawesome.io/license/

### jQuery JavaScript Library (^1.9.2)

* License: The MIT License (MIT)

### jquery.matchHeight.js (^0.7.2)

* License: The MIT License (MIT)

### Babel (^7.12.1)

* License: The MIT License (MIT)

### Browserslist (^4.16.1)

* License: The MIT License (MIT)

==> eclipsefdn-solstice-assets-0.0.264.tgz: package/NOTICE.md <==
# Notices for solstice-assets

This content is produced and maintained by the Eclipse Foundation.

* Project home: https://gitlab.eclipse.org/eclipsefdn/it/webdev/solstice-assets

## Trademarks

* Jakarta and Jakarta EE are Trademarks of the Eclipse Foundation, Inc.
* Eclipse® is a Trademark of the Eclipse Foundation, Inc.
* Eclipse Foundation is a Trademark of the Eclipse Foundation, Inc.

## Copyright

All content is the property of the respective authors or their employers. For
more information regarding authorship of content, please consult the listed
source code repository logs.

## Declared Project Licenses

This program and the accompanying materials are made available under the terms
of the Eclipse Public License v. 2.0 which is available at
http://www.eclipse.org/legal/epl-2.0.

SPDX-License-Identifier: EPL-2.0

## Source Code

The project maintains the following source code repositories:

* https://gitlab.eclipse.org/eclipsefdn/it/webdev/solstice-assets

## Third-party Content

### Drupal-Bootstrap (7.x-3.20)

* License: The GPL License (GPL)

### Yamm (master)

* License: The MIT License (MIT)

### Bootstrap (^3.3.7)

* License: The MIT License (MIT)

### Feather (^4.7.0)

* License: The MIT License (MIT)

### Font-Awesome (^4.7.0)

* The Font Awesome font is licensed under the SIL OFL 1.1:
** http://scripts.sil.org/OFL
* Font Awesome CSS, LESS, and Sass files are licensed under the MIT License:
** https://opensource.org/licenses/mit-license.html
* The Font Awesome documentation is licensed under the CC BY 3.0 License:
** https://creativecommons.org/licenses/by/3.0/
* Attribution is no longer required as of Font Awesome 3.0, but much appreciated:
** `Font Awesome by Dave Gandy - http://fontawesome.io`
* Full details: http://fontawesome.io/license/

### jQuery JavaScript Library (^1.9.2)

* License: The MIT License (MIT)

### jquery.matchHeight.js (^0.7.2)

* License: The MIT License (MIT)

### Babel (^7.12.1)

* License: The MIT License (MIT)

### Browserslist (^4.16.1)

* License: The MIT License (MIT)
